==> node-bubble-0.1.20.tgz: package/view/string-utils.js <==
var dateFormat = require("dateformat");
var configs = require("../conf/configs");

function StringUtils()
{
    this.formatDate = function (date, format, utc) {
        if (!date) {
            return "";
        }

        return dateFormat(date, format, utc);
    };

    this.getDays = function (timespan) {
        if (!timespan) {
            return 0;
        }

        return Math.floor(timespan / (1000 * 60 * 60 * 24));
    };

    this.getLongestSemanticTime = function (timespan) {
        if (!timespan) {
            return {
                time: 0,
                unit: "s"
            };
        }

        var days = timespan / (1000 * 60 * 60 * 24);
        if (Math.abs(days) > 1) {
            var months = days / 30;
            if (Math.abs(months) < 1) {
                return {
                    time: Math.floor(days),
                    unit: "d"
                };
            } else {
                var years = months / 12;
                if (Math.abs(years) < 1) {
                    return {
                        time: Math.floor(months),
                        unit: "m"
                    };
                } else {
                    return {
                        time: Math.floor(years),
                        unit: "y"
                    };
                }
            }
        } else {
            var hours = days * 24;
            if (Math.abs(hours) < 1) {
                var minutes = hours * 60;
                if (Math.abs(minutes) < 1) {
                    return {
                        time: Math.floor(minutes * 60),
                        unit: "s"
                    };
                } else {
                    return {
                        time: Math.floor(minutes),
                        unit: "M"
                    };
                }
            } else {
                return {
                    time: Math.floor(hours),
                    unit: "H"
                };
            }
        }
    };

    this.defEmpty = function (str) {
        if (!str) {
            return "";
        }

        return str;
    };

    this.toContentRoot = function (url) {
        if (url.indexOf("/") === 0) {
            url = url.substring(1);
        }

        return configs.prefix + url;
    };
}

module.exports = StringUtils;

==> node-bubble-0.3.0.tgz: package/view/string-utils.js <==
"use strict";

let dateFormat = require("dateformat");
let configs = require("../conf/configs");

function StringUtils()
{
    this.formatDate = (date, format, utc) => {
        if (!date) {
            return "";
        }

        return dateFormat(date, format, utc);
    };

    this.getDays = (timespan) => {
        if (!timespan) {
            return 0;
        }

        return Math.floor(timespan / (1000 * 60 * 60 * 24));
    };

    this.getLongestSemanticTime = (timespan) => {
        if (!timespan) {
            return {
                time: 0,
                unit: "s"
            };
        }

        let days = timespan / (1000 * 60 * 60 * 24);
        if (Math.abs(days) > 1) {
            let months = days / 30;
            if (Math.abs(months) < 1) {
                return {
                    time: Math.floor(days),
                    unit: "d"
                };
            } else {
                let years = months / 12;
                if (Math.abs(years) < 1) {
                    return {
                        time: Math.floor(months),
                        unit: "m"
                    };
                } else {
                    return {
                        time: Math.floor(years),
                        unit: "y"
                    };
                }
            }
        } else {
            let hours = days * 24;
            if (Math.abs(hours) < 1) {
                let minutes = hours * 60;
                if (Math.abs(minutes) < 1) {
                    return {
                        time: Math.floor(minutes * 60),
                        unit: "s"
                    };
                } else {
                    return {
                        time: Math.floor(minutes),
                        unit: "M"
                    };
                }
            } else {
                return {
                    time: Math.floor(hours),
                    unit: "H"
                };
            }
        }
    };

    this.defEmpty = (str) => {
        if (!str) {
            return "";
        }

        return str;
    };

    this.toContentRoot = (url) => {
        if (!url) {
            return configs.prefix;
        }

        if (url.startsWith("/")) {
            url = url.substring(1);
        }

        return configs.prefix + url;
    };
}

module.exports = StringUtils;
